{
  config,
  pkgs,
  ...
}: {
  sops.secrets."wireless.env" = {
    sopsFile = ../../secrets/wifi.yaml;
  };
  sops.age.keyFile = /home/max/.config/sops/age/keys.txt;
  networking.wireless = {
    enable = true;
    userControlled.enable = true;
    environmentFile = config.sops.secrets."wireless.env".path;
    networks = {
      "@home_uuid@" = {
        psk = "@home_psk@";
        priority = 10;
      };
      "@par_uuid@" = {
        psk = "@par_psk@";
        priority = 10;
      };
      "@luhbots_uuid@" = {
        psk = "@luhbots_psk@";
        priority = 5;
      };
      eduroam = {
        auth = ''
          key_mgmt=WPA-EAP
          proto=RSN
          pairwise=CCMP
          group=CCMP
          eap=PEAP
          phase2="auth=MSCHAPV2"
          anonymous_identity="eduroam@uni-hannover.de"
          identity="@eduroam_ident@"
          password="@eduroam_psk@"
        '';
        priority = 0;
      };
    };
  };
  users.extraUsers.max.extraGroups = ["wheel"];

  environment.systemPackages = with pkgs; [
    wpa_supplicant_gui
  ];
}
